@@ -28,6 +28,7 @@ import (
 type App struct {
 	OverrideKubeContext string
 	OverrideHelmBinary  string
+	EnableLiveOutput    bool
 
 	Logger      *zap.SugaredLogger
 	Env         string
@@ -64,6 +65,7 @@ func New(conf ConfigProvider) *App {
 	return Init(&App{
 		OverrideKubeContext: conf.KubeContext(),
 		OverrideHelmBinary:  conf.HelmBinary(),
+		EnableLiveOutput:    conf.EnableLiveOutput(),
 		Logger:              conf.Logger(),
 		Env:                 conf.Env(),
 		Namespace:           conf.Namespace(),
@@ -84,6 +86,10 @@ func Init(app *App) *App {
 		panic(fmt.Sprintf("Failed to initialize vals runtime: %v", err))
 	}
 
+	if app.EnableLiveOutput {
+		app.Logger.Info("Live output is enabled")
+	}
+
 	return app
 }
 
@@ -213,6 +219,9 @@ func (a *App) Template(c TemplateConfigProvider) error {
 	return a.ForEachState(func(run *Run) (ok bool, errs []error) {
 		includeCRDs := c.IncludeCRDs()
 
+		// Live output should never be enabled for the "template" subcommand to avoid breaking `helmfile template | kubectl apply -f -`
+		run.helm.SetEnableLiveOutput(false)
+
 		// `helm template` in helm v2 does not support local chart.
 		// So, we set forceDownload=true for helm v2 only
 		prepErr := run.withPreparedCharts("template", state.ChartPrepareOptions{
@@ -717,6 +726,7 @@ func (a *App) loadDesiredStateFromYaml(file string, opts ...LoadOpts) (*state.He
 
 		overrideKubeContext: a.OverrideKubeContext,
 		overrideHelmBinary:  a.OverrideHelmBinary,
+		enableLiveOutput:    a.EnableLiveOutput,
 		getHelm:             a.getHelm,
 		valsRuntime:         a.valsRuntime,
 	}
@@ -755,7 +765,7 @@ func (a *App) getHelm(st *state.HelmState) helmexec.Interface {
 	key := createHelmKey(bin, kubectx)
 
 	if _, ok := a.helms[key]; !ok {
-		a.helms[key] = helmexec.New(bin, a.Logger, kubectx, &helmexec.ShellRunner{
+		a.helms[key] = helmexec.New(bin, a.EnableLiveOutput, a.Logger, kubectx, &helmexec.ShellRunner{
 			Logger: a.Logger,
 		})
 	}
@@ -780,7 +790,7 @@ func (a *App) visitStates(fileOrDir string, defOpts LoadOpts, converge func(*sta
 		go func() {
 			sig := <-sigs
 
-			errs := []error{fmt.Errorf("Received [%s] to shutdown ", sig)}
+			errs := []error{fmt.Errorf("received [%s] to shutdown ", sig)}
 			_ = context{app: a, st: st, retainValues: defOpts.RetainValuesFiles}.clean(errs)
 			// See http://tldp.org/LDP/abs/html/exitcodes.html
 			switch sig {
@@ -1332,7 +1342,7 @@ Do you really want to apply?
 		a.Logger.Debug(*infoMsg)
 	}
 
-	applyErrs := []error{}
+	var applyErrs []error
 
 	affectedReleases := state.AffectedReleases{}
 
@@ -1345,15 +1355,27 @@ Do you really want to apply?
 		// We deleted releases by traversing the DAG in reverse order
 		if len(releasesToBeDeleted) > 0 {
 			_, deletionErrs := withDAG(st, helm, a.Logger, state.PlanOptions{Reverse: true, SelectedReleases: toDelete, SkipNeeds: true}, a.WrapWithoutSelector(func(subst *state.HelmState, helm helmexec.Interface) []error {
-				var rs []state.ReleaseSpec
+				var (
+					rs             []state.ReleaseSpec
+					preapplyErrors []error
+				)
 
 				for _, r := range subst.Releases {
 					release := r
 					if r2, ok := releasesToBeDeleted[state.ReleaseToID(&release)]; ok {
+						if _, err := st.TriggerPreapplyEvent(&r2, "apply"); err != nil {
+							preapplyErrors = append(applyErrs, err)
+							continue
+						}
+
 						rs = append(rs, r2)
 					}
 				}
 
+				if len(preapplyErrors) > 0 {
+					return preapplyErrors
+				}
+
 				subst.Releases = rs
 
 				return subst.DeleteReleasesForSync(&affectedReleases, helm, c.Concurrency())
@@ -1367,15 +1389,27 @@ Do you really want to apply?
 		// We upgrade releases by traversing the DAG
 		if len(releasesToBeUpdated) > 0 {
 			_, updateErrs := withDAG(st, helm, a.Logger, state.PlanOptions{SelectedReleases: toUpdate, Reverse: false, SkipNeeds: true, IncludeTransitiveNeeds: c.IncludeTransitiveNeeds()}, a.WrapWithoutSelector(func(subst *state.HelmState, helm helmexec.Interface) []error {
-				var rs []state.ReleaseSpec
+				var (
+					rs             []state.ReleaseSpec
+					preapplyErrors []error
+				)
 
 				for _, r := range subst.Releases {
 					release := r
 					if r2, ok := releasesToBeUpdated[state.ReleaseToID(&release)]; ok {
+						if _, err := st.TriggerPreapplyEvent(&r2, "apply"); err != nil {
+							preapplyErrors = append(applyErrs, err)
+							continue
+						}
+
 						rs = append(rs, r2)
 					}
 				}
 
+				if len(preapplyErrors) > 0 {
+					return preapplyErrors
+				}
+
 				subst.Releases = rs
 
 				syncOpts := state.SyncOpts{
@@ -1832,12 +1866,12 @@ func (a *App) withNeeds(r *Run, c DAGConfig, includeDisabled bool, f func(*state
 
 	var toRender []state.ReleaseSpec
 
-	releasesDisabled := map[string]state.ReleaseSpec{}
+	releasesToUninstall := map[string]state.ReleaseSpec{}
 	for _, r := range selectedReleasesWithNeeds {
 		release := r
 		id := state.ReleaseToID(&release)
 		if release.Installed != nil && !*release.Installed {
-			releasesDisabled[id] = release
+			releasesToUninstall[id] = release
 		} else {
 			toRender = append(toRender, release)
 		}
@@ -1845,19 +1879,21 @@ func (a *App) withNeeds(r *Run, c DAGConfig, includeDisabled bool, f func(*state
 
 	var rels []state.ReleaseSpec
 
-	// toRender already contains the direct and transitive needs depending on the DAG options.
-	// That's why we don't pass in `IncludeNeeds: c.IncludeNeeds(), IncludeTransitiveNeeds: c.IncludeTransitiveNeeds()` here.
-	// Otherwise, in case include-needs=true, it will include the needs of needs, which results in unexpectedly introducing transitive needs,
-	// even if include-transitive-needs=true is unspecified.
-	if _, errs := withDAG(st, r.helm, a.Logger, state.PlanOptions{SelectedReleases: toRender, Reverse: false, SkipNeeds: c.SkipNeeds(), IncludeNeeds: includeNeeds}, a.WrapWithoutSelector(func(subst *state.HelmState, helm helmexec.Interface) []error {
-		rels = append(rels, subst.Releases...)
-		return nil
-	})); len(errs) > 0 {
-		return false, errs
+	if len(toRender) > 0 {
+		// toRender already contains the direct and transitive needs depending on the DAG options.
+		// That's why we don't pass in `IncludeNeeds: c.IncludeNeeds(), IncludeTransitiveNeeds: c.IncludeTransitiveNeeds()` here.
+		// Otherwise, in case include-needs=true, it will include the needs of needs, which results in unexpectedly introducing transitive needs,
+		// even if include-transitive-needs=true is unspecified.
+		if _, errs := withDAG(st, r.helm, a.Logger, state.PlanOptions{SelectedReleases: toRender, Reverse: false, SkipNeeds: c.SkipNeeds(), IncludeNeeds: includeNeeds}, a.WrapWithoutSelector(func(subst *state.HelmState, helm helmexec.Interface) []error {
+			rels = append(rels, subst.Releases...)
+			return nil
+		})); len(errs) > 0 {
+			return false, errs
+		}
 	}
 
 	if includeDisabled {
-		for _, d := range releasesDisabled {
+		for _, d := range releasesToUninstall {
 			rels = append(rels, d)
 		}
 	}
