@@ -5,6 +5,7 @@ import "go.uber.org/zap"
 type ConfigProvider interface {
 	Args() string
 	HelmBinary() string
+	EnableLiveOutput() bool
 
 	FileOrDir() string
 	KubeContext() string
@@ -54,6 +55,7 @@ type ApplyConfigProvider interface {
 	Suppress() []string
 	SuppressSecrets() bool
 	ShowSecrets() bool
+	NoHooks() bool
 	SuppressDiff() bool
 
 	DetailedExitcode() bool
@@ -111,6 +113,7 @@ type DiffConfigProvider interface {
 	Suppress() []string
 	SuppressSecrets() bool
 	ShowSecrets() bool
+	NoHooks() bool
 	SuppressDiff() bool
 	SkipDiffOnInstall() bool
 
