@@ -42,6 +42,8 @@ type ApplyOptions struct {
 	SuppressSecrets bool
 	// SuppressDiff is true if the diff should be suppressed
 	ShowSecrets bool
+	// NoHooks skips checking for hooks
+	NoHooks bool
 	// SkipDeps is true if the running "helm repo update" and "helm dependency build" should be skipped
 	SuppressDiff bool
 	// ShowSecrets is true if the secrets should be shown
@@ -50,8 +52,6 @@ type ApplyOptions struct {
 	Wait bool
 	// WaitForJobs is true if the helm command should wait for the jobs to be completed
 	WaitForJobs bool
-	// Interactive is true if the user should be prompted for input.
-	Interactive bool
 }
 
 // NewApply creates a new Apply
@@ -135,6 +135,11 @@ func (a *ApplyImpl) ShowSecrets() bool {
 	return a.ApplyOptions.ShowSecrets
 }
 
+// NoHooks skips hooks.
+func (a *ApplyImpl) NoHooks() bool {
+	return a.ApplyOptions.NoHooks
+}
+
 // SkipCRDs returns the skip crds.
 func (a *ApplyImpl) SkipCRDs() bool {
 	return a.ApplyOptions.SkipCRDs
@@ -197,8 +202,3 @@ func (a *ApplyImpl) Wait() bool {
 func (a *ApplyImpl) WaitForJobs() bool {
 	return a.ApplyOptions.WaitForJobs
 }
-
-// Interactive returns the Interactive.
-func (a *ApplyImpl) Interactive() bool {
-	return a.ApplyOptions.Interactive
-}
