@@ -26,8 +26,6 @@ type SyncOptions struct {
 	Wait bool
 	// WaitForJobs is the wait for jobs flag
 	WaitForJobs bool
-	// Interactive is true if the user should be prompted for input.
-	Interactive bool
 }
 
 // NewSyncOptions creates a new Apply
@@ -112,8 +110,3 @@ func (t *SyncImpl) Wait() bool {
 func (t *SyncImpl) WaitForJobs() bool {
 	return t.SyncOptions.WaitForJobs
 }
-
-// Interactive returns the Interactive
-func (t *SyncImpl) Interactive() bool {
-	return t.SyncOptions.Interactive
-}
