@@ -89,6 +89,8 @@ func (helm *Helm) SetExtraArgs(args ...string) {
 }
 func (helm *Helm) SetHelmBinary(bin string) {
 }
+func (helm *Helm) SetEnableLiveOutput(enableLiveOutput bool) {
+}
 func (helm *Helm) AddRepo(name, repository, cafile, certfile, keyfile, username, password string, managed string, passCredentials string, skipTLSVerify string) error {
 	helm.Repo = []string{name, repository, cafile, certfile, keyfile, username, password, managed, passCredentials, skipTLSVerify}
 	return nil
@@ -159,7 +161,7 @@ func (helm *Helm) List(context helmexec.HelmContext, filter string, flags ...str
 		for k := range helm.Lists {
 			keys = append(keys, k.String())
 		}
-		return "", fmt.Errorf("unexpected list key: %v in %v", key, strings.Join(keys, ", "))
+		return "", fmt.Errorf("unexpected list key: %v not found in %v", key, strings.Join(keys, ", "))
 	}
 	return res, nil
 }
@@ -190,7 +192,7 @@ func (helm *Helm) TemplateRelease(name, chart string, flags ...string) error {
 	helm.Templated = append(helm.Templated, Release{Name: name, Flags: flags})
 	return nil
 }
-func (helm *Helm) ChartPull(chart string, flags ...string) error {
+func (helm *Helm) ChartPull(chart string, path string, flags ...string) error {
 	return nil
 }
 func (helm *Helm) ChartExport(chart string, path string, flags ...string) error {
